# Generated by roxygen2: do not edit by hand

S3method(activate,grouped_tbl_graph)
S3method(activate,morphed_tbl_graph)
S3method(activate,tbl_graph)
S3method(anti_join,tbl_graph)
S3method(arrange,morphed_tbl_graph)
S3method(arrange,tbl_graph)
S3method(as.data.frame,tbl_graph)
S3method(as.igraph,tbl_graph)
S3method(as.list,tbl_graph)
S3method(as_tbl_graph,Node)
S3method(as_tbl_graph,data.frame)
S3method(as_tbl_graph,default)
S3method(as_tbl_graph,dendrogram)
S3method(as_tbl_graph,evonet)
S3method(as_tbl_graph,graphAM)
S3method(as_tbl_graph,graphBAM)
S3method(as_tbl_graph,graphNEL)
S3method(as_tbl_graph,hclust)
S3method(as_tbl_graph,igraph)
S3method(as_tbl_graph,list)
S3method(as_tbl_graph,matrix)
S3method(as_tbl_graph,network)
S3method(as_tbl_graph,phylo)
S3method(as_tbl_graph,tbl_graph)
S3method(as_tibble,tbl_graph)
S3method(convert,tbl_graph)
S3method(crystallise,morphed_tbl_graph)
S3method(distinct,morphed_tbl_graph)
S3method(distinct,tbl_graph)
S3method(filter,morphed_tbl_graph)
S3method(filter,tbl_graph)
S3method(full_join,tbl_graph)
S3method(group_by,morphed_tbl_graph)
S3method(group_by,tbl_graph)
S3method(group_size,grouped_tbl_graph)
S3method(group_vars,grouped_tbl_graph)
S3method(groups,grouped_tbl_graph)
S3method(groups,tbl_graph)
S3method(inner_join,tbl_graph)
S3method(left_join,tbl_graph)
S3method(morph,morphed_tbl_graph)
S3method(morph,tbl_graph)
S3method(mutate,morphed_tbl_graph)
S3method(mutate,tbl_graph)
S3method(n_groups,grouped_tbl_graph)
S3method(print,morphed_tbl_graph)
S3method(print,tbl_graph)
S3method(pull,morphed_tbl_graph)
S3method(pull,tbl_graph)
S3method(rename,morphed_tbl_graph)
S3method(rename,tbl_graph)
S3method(reroute,morphed_tbl_graph)
S3method(reroute,tbl_graph)
S3method(right_join,tbl_graph)
S3method(sample_frac,morphed_tbl_graph)
S3method(sample_frac,tbl_graph)
S3method(sample_n,morphed_tbl_graph)
S3method(sample_n,tbl_graph)
S3method(select,morphed_tbl_graph)
S3method(select,tbl_graph)
S3method(semi_join,tbl_graph)
S3method(slice,morphed_tbl_graph)
S3method(slice,tbl_graph)
S3method(tbl_vars,tbl_graph)
S3method(ungroup,grouped_tbl_graph)
S3method(ungroup,morphed_tbl_graph)
S3method(ungroup,tbl_graph)
S3method(unmorph,morphed_tbl_graph)
export("%>%")
export("%E>%")
export("%N>%")
export(.E)
export(.G)
export(.N)
export(.graph_context)
export(.register_graph_context)
export(activate)
export(active)
export(anti_join)
export(arrange)
export(as.igraph)
export(as_tbl_graph)
export(as_tibble)
export(bfs_after)
export(bfs_before)
export(bfs_dist)
export(bfs_parent)
export(bfs_rank)
export(bind_edges)
export(bind_graphs)
export(bind_nodes)
export(centrality_alpha)
export(centrality_authority)
export(centrality_betweenness)
export(centrality_betweenness_communicability)
export(centrality_betweenness_current)
export(centrality_betweenness_network)
export(centrality_betweenness_rsp_net)
export(centrality_betweenness_rsp_simple)
export(centrality_closeness)
export(centrality_closeness_generalised)
export(centrality_closeness_harmonic)
export(centrality_closeness_residual)
export(centrality_communicability)
export(centrality_communicability_even)
export(centrality_communicability_odd)
export(centrality_decay)
export(centrality_degree)
export(centrality_edge_betweenness)
export(centrality_eigen)
export(centrality_expected)
export(centrality_hub)
export(centrality_information)
export(centrality_integration)
export(centrality_katz)
export(centrality_manual)
export(centrality_pagerank)
export(centrality_power)
export(centrality_random_walk)
export(centrality_subgraph)
export(centrality_subgraph_even)
export(centrality_subgraph_odd)
export(contains)
export(convert)
export(create_bipartite)
export(create_chordal_ring)
export(create_citation)
export(create_complete)
export(create_de_bruijn)
export(create_empty)
export(create_kautz)
export(create_lattice)
export(create_notable)
export(create_path)
export(create_ring)
export(create_star)
export(create_tree)
export(crystallise)
export(crystallize)
export(dfs_dist)
export(dfs_parent)
export(dfs_rank)
export(dfs_rank_out)
export(distinct)
export(edge_is_between)
export(edge_is_from)
export(edge_is_incident)
export(edge_is_loop)
export(edge_is_multiple)
export(edge_is_mutual)
export(edge_is_to)
export(ends_with)
export(everything)
export(filter)
export(fortify.tbl_graph)
export(full_join)
export(graph_adhesion)
export(graph_assortativity)
export(graph_asym_count)
export(graph_automorphisms)
export(graph_clique_count)
export(graph_clique_num)
export(graph_component_count)
export(graph_diameter)
export(graph_girth)
export(graph_is_bipartite)
export(graph_is_chordal)
export(graph_is_complete)
export(graph_is_connected)
export(graph_is_dag)
export(graph_is_directed)
export(graph_is_forest)
export(graph_is_isomorphic_to)
export(graph_is_simple)
export(graph_is_subgraph_isomorphic_to)
export(graph_is_tree)
export(graph_join)
export(graph_mean_dist)
export(graph_min_cut)
export(graph_motif_count)
export(graph_mutual_count)
export(graph_order)
export(graph_radius)
export(graph_reciprocity)
export(graph_size)
export(graph_unconn_count)
export(group_biconnected_component)
export(group_by)
export(group_components)
export(group_edge_betweenness)
export(group_fast_greedy)
export(group_infomap)
export(group_label_prop)
export(group_leading_eigen)
export(group_louvain)
export(group_optimal)
export(group_size)
export(group_spinglass)
export(group_vars)
export(group_walktrap)
export(groups)
export(inner_join)
export(is.tbl_graph)
export(left_join)
export(local_ave_degree)
export(local_members)
export(local_size)
export(local_transitivity)
export(local_triangles)
export(map_bfs)
export(map_bfs_back)
export(map_bfs_back_chr)
export(map_bfs_back_dbl)
export(map_bfs_back_int)
export(map_bfs_back_lgl)
export(map_bfs_chr)
export(map_bfs_dbl)
export(map_bfs_int)
export(map_bfs_lgl)
export(map_dfs)
export(map_dfs_back)
export(map_dfs_back_chr)
export(map_dfs_back_dbl)
export(map_dfs_back_int)
export(map_dfs_back_lgl)
export(map_dfs_chr)
export(map_dfs_dbl)
export(map_dfs_int)
export(map_dfs_lgl)
export(map_local)
export(map_local_chr)
export(map_local_dbl)
export(map_local_int)
export(map_local_lgl)
export(matches)
export(morph)
export(mutate)
export(mutate_all)
export(mutate_as_tbl)
export(mutate_at)
export(n)
export(n_groups)
export(node_adhesion_from)
export(node_adhesion_to)
export(node_bibcoupling_with)
export(node_bridging_score)
export(node_closeness_impact)
export(node_cocitation_with)
export(node_cohesion_from)
export(node_cohesion_to)
export(node_connectivity_impact)
export(node_constraint)
export(node_coreness)
export(node_distance_from)
export(node_distance_to)
export(node_diversity)
export(node_dominator)
export(node_eccentricity)
export(node_effective_network_size)
export(node_fareness_impact)
export(node_is_adjacent)
export(node_is_center)
export(node_is_cut)
export(node_is_isolated)
export(node_is_keyplayer)
export(node_is_leaf)
export(node_is_root)
export(node_is_simplical)
export(node_is_sink)
export(node_is_source)
export(node_is_universal)
export(node_max_flow_from)
export(node_max_flow_to)
export(node_rank_anneal)
export(node_rank_branch_bound)
export(node_rank_dendser)
export(node_rank_genetic)
export(node_rank_hclust)
export(node_rank_leafsort)
export(node_rank_mds)
export(node_rank_quadratic)
export(node_rank_spectral)
export(node_rank_spin_in)
export(node_rank_spin_out)
export(node_rank_traveller)
export(node_rank_two)
export(node_rank_visual)
export(node_similarity_with)
export(node_topo_order)
export(num_range)
export(one_of)
export(play_barabasi_albert)
export(play_barabasi_albert_aging)
export(play_bipartite)
export(play_blocks)
export(play_blocks_hierarchy)
export(play_citation_age)
export(play_citation_type)
export(play_degree)
export(play_dotprod)
export(play_erdos_renyi)
export(play_fitness)
export(play_fitness_power)
export(play_forestfire)
export(play_geometry)
export(play_growing)
export(play_islands)
export(play_preference)
export(play_preference_asym)
export(play_smallworld)
export(play_traits)
export(pull)
export(rename)
export(reroute)
export(right_join)
export(sample_frac)
export(sample_n)
export(select)
export(semi_join)
export(slice)
export(starts_with)
export(tbl_graph)
export(to_bfs_tree)
export(to_complement)
export(to_components)
export(to_contracted)
export(to_dfs_tree)
export(to_directed)
export(to_dominator_tree)
export(to_hierarchical_clusters)
export(to_linegraph)
export(to_local_neighborhood)
export(to_minimum_spanning_tree)
export(to_shortest_path)
export(to_simple)
export(to_split)
export(to_subcomponent)
export(to_subgraph)
export(to_undirected)
export(to_unfolded_tree)
export(top_n)
export(transmute)
export(ungroup)
export(unmorph)
export(with_graph)
importFrom(R6,R6Class)
importFrom(Rcpp,sourceCpp)
importFrom(dplyr,anti_join)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,contains)
importFrom(dplyr,distinct)
importFrom(dplyr,ends_with)
importFrom(dplyr,everything)
importFrom(dplyr,filter)
importFrom(dplyr,full_join)
importFrom(dplyr,group_by)
importFrom(dplyr,group_size)
importFrom(dplyr,group_vars)
importFrom(dplyr,groups)
importFrom(dplyr,inner_join)
importFrom(dplyr,left_join)
importFrom(dplyr,matches)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_all)
importFrom(dplyr,mutate_at)
importFrom(dplyr,n)
importFrom(dplyr,n_groups)
importFrom(dplyr,num_range)
importFrom(dplyr,one_of)
importFrom(dplyr,pull)
importFrom(dplyr,rename)
importFrom(dplyr,right_join)
importFrom(dplyr,sample_frac)
importFrom(dplyr,sample_n)
importFrom(dplyr,select)
importFrom(dplyr,semi_join)
importFrom(dplyr,slice)
importFrom(dplyr,starts_with)
importFrom(dplyr,tbl_vars)
importFrom(dplyr,top_n)
importFrom(dplyr,transmute)
importFrom(dplyr,ungroup)
importFrom(igraph,"edge_attr<-")
importFrom(igraph,"graph_attr<-")
importFrom(igraph,"vertex_attr<-")
importFrom(igraph,E)
importFrom(igraph,V)
importFrom(igraph,add_edges)
importFrom(igraph,add_vertices)
importFrom(igraph,adjacent_vertices)
importFrom(igraph,alpha_centrality)
importFrom(igraph,articulation_points)
importFrom(igraph,as.igraph)
importFrom(igraph,as_adjacency_matrix)
importFrom(igraph,as_data_frame)
importFrom(igraph,as_edgelist)
importFrom(igraph,assortativity)
importFrom(igraph,assortativity_nominal)
importFrom(igraph,authority_score)
importFrom(igraph,automorphisms)
importFrom(igraph,betweenness)
importFrom(igraph,bfs)
importFrom(igraph,bibcoupling)
importFrom(igraph,biconnected_components)
importFrom(igraph,clique_num)
importFrom(igraph,closeness)
importFrom(igraph,cluster_edge_betweenness)
importFrom(igraph,cluster_fast_greedy)
importFrom(igraph,cluster_infomap)
importFrom(igraph,cluster_label_prop)
importFrom(igraph,cluster_leading_eigen)
importFrom(igraph,cluster_louvain)
importFrom(igraph,cluster_optimal)
importFrom(igraph,cluster_spinglass)
importFrom(igraph,cluster_walktrap)
importFrom(igraph,cocitation)
importFrom(igraph,complementer)
importFrom(igraph,components)
importFrom(igraph,constraint)
importFrom(igraph,contract)
importFrom(igraph,coreness)
importFrom(igraph,count_components)
importFrom(igraph,count_max_cliques)
importFrom(igraph,count_motifs)
importFrom(igraph,count_triangles)
importFrom(igraph,decompose)
importFrom(igraph,degree)
importFrom(igraph,delete_edges)
importFrom(igraph,delete_vertices)
importFrom(igraph,dfs)
importFrom(igraph,diameter)
importFrom(igraph,distances)
importFrom(igraph,diversity)
importFrom(igraph,dominator_tree)
importFrom(igraph,dyad_census)
importFrom(igraph,eccentricity)
importFrom(igraph,ecount)
importFrom(igraph,edge_attr)
importFrom(igraph,edge_attr_names)
importFrom(igraph,edge_betweenness)
importFrom(igraph,edge_connectivity)
importFrom(igraph,ego)
importFrom(igraph,ego_size)
importFrom(igraph,eigen_centrality)
importFrom(igraph,estimate_betweenness)
importFrom(igraph,estimate_closeness)
importFrom(igraph,estimate_edge_betweenness)
importFrom(igraph,girth)
importFrom(igraph,gorder)
importFrom(igraph,graph_attr)
importFrom(igraph,graph_from_adj_list)
importFrom(igraph,graph_from_adjacency_matrix)
importFrom(igraph,graph_from_data_frame)
importFrom(igraph,graph_from_edgelist)
importFrom(igraph,graph_from_incidence_matrix)
importFrom(igraph,gsize)
importFrom(igraph,hub_score)
importFrom(igraph,induced_subgraph)
importFrom(igraph,is.directed)
importFrom(igraph,is_bipartite)
importFrom(igraph,is_chordal)
importFrom(igraph,is_connected)
importFrom(igraph,is_dag)
importFrom(igraph,is_directed)
importFrom(igraph,is_isomorphic_to)
importFrom(igraph,is_simple)
importFrom(igraph,is_subgraph_isomorphic_to)
importFrom(igraph,knn)
importFrom(igraph,local_scan)
importFrom(igraph,make_chordal_ring)
importFrom(igraph,make_de_bruijn_graph)
importFrom(igraph,make_ego_graph)
importFrom(igraph,make_empty_graph)
importFrom(igraph,make_full_bipartite_graph)
importFrom(igraph,make_full_citation_graph)
importFrom(igraph,make_full_graph)
importFrom(igraph,make_graph)
importFrom(igraph,make_kautz_graph)
importFrom(igraph,make_lattice)
importFrom(igraph,make_line_graph)
importFrom(igraph,make_ring)
importFrom(igraph,make_star)
importFrom(igraph,make_tree)
importFrom(igraph,max_flow)
importFrom(igraph,mean_distance)
importFrom(igraph,membership)
importFrom(igraph,min_cut)
importFrom(igraph,mst)
importFrom(igraph,page_rank)
importFrom(igraph,permute)
importFrom(igraph,power_centrality)
importFrom(igraph,radius)
importFrom(igraph,reciprocity)
importFrom(igraph,sample_asym_pref)
importFrom(igraph,sample_bipartite)
importFrom(igraph,sample_cit_cit_types)
importFrom(igraph,sample_cit_types)
importFrom(igraph,sample_degseq)
importFrom(igraph,sample_dot_product)
importFrom(igraph,sample_fitness)
importFrom(igraph,sample_fitness_pl)
importFrom(igraph,sample_forestfire)
importFrom(igraph,sample_gnm)
importFrom(igraph,sample_gnp)
importFrom(igraph,sample_grg)
importFrom(igraph,sample_growing)
importFrom(igraph,sample_hierarchical_sbm)
importFrom(igraph,sample_islands)
importFrom(igraph,sample_last_cit)
importFrom(igraph,sample_pa)
importFrom(igraph,sample_pa_age)
importFrom(igraph,sample_pref)
importFrom(igraph,sample_sbm)
importFrom(igraph,sample_smallworld)
importFrom(igraph,sample_traits)
importFrom(igraph,sample_traits_callaway)
importFrom(igraph,set_edge_attr)
importFrom(igraph,set_vertex_attr)
importFrom(igraph,shortest_paths)
importFrom(igraph,similarity)
importFrom(igraph,simplify)
importFrom(igraph,strength)
importFrom(igraph,subgraph.edges)
importFrom(igraph,subgraph_centrality)
importFrom(igraph,topo_sort)
importFrom(igraph,transitivity)
importFrom(igraph,unfold_tree)
importFrom(igraph,vertex_attr)
importFrom(igraph,vertex_attr_names)
importFrom(igraph,vertex_connectivity)
importFrom(igraph,which_loop)
importFrom(igraph,which_multiple)
importFrom(igraph,which_mutual)
importFrom(magrittr,"%>%")
importFrom(pillar,style_subtle)
importFrom(rlang,"!!!")
importFrom(rlang,"%||%")
importFrom(rlang,.data)
importFrom(rlang,UQS)
importFrom(rlang,as_quosure)
importFrom(rlang,caller_env)
importFrom(rlang,enexpr)
importFrom(rlang,enquo)
importFrom(rlang,eval_bare)
importFrom(rlang,eval_tidy)
importFrom(rlang,quo)
importFrom(rlang,quo_text)
importFrom(rlang,quos)
importFrom(rlang,sym)
importFrom(stats,as.dendrogram)
importFrom(stats,as.dist)
importFrom(stats,dist)
importFrom(stats,hclust)
importFrom(stats,is.leaf)
importFrom(stats,na.omit)
importFrom(stats,setNames)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(tibble,trunc_mat)
importFrom(tidyr,nest)
importFrom(tools,toTitleCase)
importFrom(utils,head)
importFrom(utils,modifyList)
useDynLib(tidygraph)
